SystemOrganization addCategory: #'MEG-Tests'!
SystemOrganization addCategory: 'MEG-Tests-Integration-Interaction'!
SystemOrganization addCategory: 'MEG-Tests-Integration-Movie'!
SystemOrganization addCategory: 'MEG-Tests-Unit'!

TestCase subclass: #EruCreatesTheWorld
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Integration-Movie'!

!EruCreatesTheWorld methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:28'!
test_01_WorldCreation

	| world gandalf rivendel elrond spawn |
	world := MEGWorld new.
	rivendel := MEGSite named: 'Rivendel'.
	gandalf := MEGCharacter named: 'Gandalf' homeSiteType: 'Haven'.
	elrond := MEGCharacter named: 'Elrond' homeSiteNamed: 'Rivendel'.
	spawn := MEGRecruitCharacterAction new.
	
	world addSite: rivendel.
	world addCharacter: gandalf.
	world addCharacter: elrond.
	
! !

!EruCreatesTheWorld methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 18:19'!
test_02_SitesForCharactersShouldAlreadyBeInTheWorld

	| world gandalf rivendel elrond |
	world := MEGWorld new.
	rivendel := MEGSite named: 'Rivendell'.
	gandalf := MEGCharacter named: 'Gandalf' homeSiteType: 'Haven'.
	elrond := MEGCharacter named: 'Elrond' homeSiteNamed: 'Rivendell'.
	
	self should: [world addCharacter: elrond] raise: NotFound.
	world addSite: rivendel.
	world addCharacter: gandalf.
	
! !

TestCase subclass: #HomeSiteCriteriaTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!HomeSiteCriteriaTest commentStamp: '<historical>' prior: 0!
A HomeSiteCriteriaTest is a test class for testing the behavior of HomeSiteCriteria!

!HomeSiteCriteriaTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:26'!
test_01_CreationOfNamedCriteria

	| criteria |
	criteria := HomeSiteCriteria named: 'Rivendel'.
! !

!HomeSiteCriteriaTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:26'!
test_02_CreationOfTypeCriteria

	| criteria |
	criteria := HomeSiteCriteria type: 'Haven'.
! !

TestCase subclass: #MEGCharacterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGCharacterTest commentStamp: '<historical>' prior: 0!
A MEGCharacterTest is a test class for testing the behavior of MEGCharacter!

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:45'!
test_01_Defaults

	| character |
	character := MEGCharacter new.
	self assert: character name isNil.
	self assert: character homeSiteCriteria isNil.
	self assert: character companies isEmpty.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:35'!
test_02_CreationWithHomeSiteNamed
	| character |
	character := MEGCharacter named: 'Bilbo' homeSiteNamed: 'Bag Ends'.
	self assert: character name = 'Bilbo'.
	self assert: character homeSiteCriteria notNil.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:45'!
test_03_CreationWithHomeSiteType
	| character |
	character := MEGCharacter named: 'Bilbo' homeSiteType: 'Haven'.
	self assert: character name = 'Bilbo'.
	self assert: character homeSiteCriteria notNil.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:10'!
test_04_SettingFollowedCharacter

	| character pipo |
	pipo := (MEGCharacter named: 'Pipo Pescador' homeSiteNamed: 'Lago Traful').
	character := MEGCharacter new.
	character characterFollowed: pipo.
	self assert: character characterFollowed = pipo.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:12'!
test_05_SettingCurrentSite

	| character site |
	site := MEGSite named: 'Lago Traful'.
	character := MEGCharacter new.
	character currentSite: site.
	self assert: character currentSite = site.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:34'!
test_06_Recruiting

	| colonel world rambo pueblito |
	world := MEGWorld new.
	colonel := MEGCharacter named: 'Sam Trautman' homeSiteNamed: 'USA'.
	colonel world: world.
	rambo := MEGCharacter named: 'Rambo' homeSiteNamed: 'Bowie, Arizona'.
	pueblito := MEGSite named: 'Hope, Washington'.
	colonel recruit: rambo at: pueblito.! !

TestCase subclass: #MEGRecruitCharacterActionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGRecruitCharacterActionTest commentStamp: '<historical>' prior: 0!
A MEGRecruitCharacterActionTest is a test class for testing the behavior of MEGRecruitCharacterAction!

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:05'!
test_01_Defaults

	| action |
	action := MEGRecruitCharacterAction new.
	self assert: action recruitee isNil.
	self assert: action recruiter isNil.
	self assert: action site isNil.
	self assert: action world isNil.! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:25'!
test_02_ConstructorMethod

	| world action |
	world := MEGWorld new.
	action := MEGRecruitCharacterAction world: world.
	self assert: action world = world.
	! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:22'!
test_03_SetRecrutee

	| action recrutee |
	recrutee := MEGCharacter named: 'Rambo' homeSiteNamed: 'Arizona'.
	action := MEGRecruitCharacterAction new.
	action recruitee: recrutee.
	self assert: action recruitee = recrutee.
! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:19'!
test_04_SetRecruiter

	| action recruiter |
	recruiter := MEGCharacter named: 'Sam Trautman' homeSiteNamed: 'USA'.
	action := MEGRecruitCharacterAction new.
	action recruiter: recruiter.
	self assert: action recruiter = recruiter.
! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:22'!
test_05_SetSite

	| action site |
	site := MEGSite named: 'Hope, Washington'.
	action := MEGRecruitCharacterAction new.
	action site: site.
	self assert: action site = site.
! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:28'!
test_06_Creation

	| world action recrutee recruiter site |
	world := MEGWorld new.
	action := MEGRecruitCharacterAction world: world.
	recrutee := MEGCharacter named: 'Rambo' homeSiteNamed: 'Arizona'.
	recruiter := MEGCharacter named: 'Sam Trautman' homeSiteNamed: 'USA'.
	site := MEGSite named: 'Hope, Washington'.
	
	action recruiter: recruiter.
	action recruitee: recrutee.
	action site: site.
	action perform.! !

TestCase subclass: #MEGSiteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGSiteTest commentStamp: '<historical>' prior: 0!
A MEGSiteTest is a test class for testing the behavior of MEGSite!

!MEGSiteTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:30'!
test_01_Defaults

	| site |
	site := MEGSite new.
	self assert: site name isNil.! !

!MEGSiteTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:30'!
test_02_Creation

	| site |
	site := MEGSite named: 'Dol-Amroth'.
	self assert: site name = 'Dol-Amroth'.! !

TestCase subclass: #MEGWorldTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGWorldTest commentStamp: '<historical>' prior: 0!
A MEGWorldTest is a test class for testing the behavior of MEGWorld!

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 08:31'!
test_01_Creation

	| world |
	world := MEGWorld new.
	self assert: world locations isEmpty.
	self assert: world characters isEmpty.! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:19'!
test_02_AddSite

	| world |
	world := MEGWorld new.
	world addSite: (MEGSite named: 'Lothlorien').
	self assert: world locations notEmpty.
	self assert: world locations size = 1.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'FedericoFigueredo 5/27/2016 08:17'!
test_03_AddCharacter

	| world |
	world := MEGWorld new.
	world addCharacter: (MEGCharacter named: 'Frodo' homeSiteNamed: 'Bag End').
	self assert: world characters notEmpty.
	self assert: world characters size = 1.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 17:23'!
test_04_RetrieveSite

	| world  |
	world := MEGWorld new.
	self should: [world siteNamed: 'Rivendell'] raise: NotFound.
	world addSite: (MEGSite named: 'Rivendell').
	self assert: (world siteNamed: 'Rivendell') notNil.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:43'!
test_05_RetrieveCharacter

	| world  |
	world := MEGWorld new.
	self should: [world characterNamed: 'Eowyn'] raise: NotFound.
	world addCharacter: (MEGCharacter named: 'Eowyn' homeSiteNamed: 'Rohan').
	self assert: (world characterNamed: 'Eowyn') notNil.
! !

TestCase subclass: #TheCompanyFormsAtRivendel
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Integration-Interaction'!

!TheCompanyFormsAtRivendel methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 11:52'!
newWorld

	| world |
	world := MEGWorldFactory new newWorld.	
	^world.! !

!TheCompanyFormsAtRivendel methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 11:29'!
newWorldWithCharacterPlayed: aString at: aString2 for: aString3

	| world |
	world := self newWorld.
	(world agentNamed: aString3) recruit: (world characterNamed: aString) at: (world siteNamed: aString2).
	^world.! !

!TheCompanyFormsAtRivendel methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 17:22'!
test_01_WizardRecruitsGandalf

	| world rivendel gandalf wizard |
	world := self newWorld.
	rivendel := world siteNamed: 'Rivendell'.
	gandalf := world characterNamed: 'Gandalf'.
	wizard := world agentNamed: 'Jugador 1'.
	
	self assert: gandalf characterFollowed isNil.
	self assert: gandalf currentSite isNil.
	self deny: (wizard followers includes: gandalf).
	self deny: (rivendel occupants includes: gandalf).
	self assert: wizard currentGeneralInfluence = 20.
	wizard recruit: gandalf at: rivendel.
	self assert: (gandalf characterFollowed) = wizard.
	self assert: (gandalf currentSite) = rivendel.
	self assert: (wizard followers includes: gandalf).
	self assert: (rivendel occupants includes: gandalf).
	self assert: wizard currentGeneralInfluence = 20.! !

!TheCompanyFormsAtRivendel methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 17:23'!
test_02_WizardRecruitsElrondIntoGeneralInfluence

	| world rivendel elrond wizard |
	world := self newWorld.
	rivendel := world siteNamed: 'Rivendell'.
	elrond := world characterNamed: 'Elrond'.
	wizard := world agentNamed: 'Jugador 1'.
	
	self assert: elrond characterFollowed isNil.
	self assert: elrond currentSite isNil.
	self deny: (wizard followers includes: elrond).
	self deny: (rivendel occupants includes: elrond).
	self assert: wizard currentGeneralInfluence = 20.
	wizard recruit: elrond at: rivendel.
	self assert: (elrond agentFollowed) = wizard.
	self assert: (elrond currentSite) = rivendel.
	self assert: (wizard followers includes: elrond).
	self assert: (rivendel occupants includes: elrond).
	self assert: wizard currentGeneralInfluence = 10.! !

!TheCompanyFormsAtRivendel methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:37'!
test_03_WizardRecruitsElrondIntoGandalfsInfluence

	| world rivendel gandalf elrond wizard |
	world := self newWorldWithCharacterPlayed: 'Gandalf' at: 'Rivendell' for: 'Jugador 1'.
	rivendel := world siteNamed: 'Rivendell'.
	gandalf := world characterNamed: 'Gandalf'.
	elrond := world characterNamed: 'Elrond'.
	wizard := world wizardNamed: 'Jugador 1'.
	
	self assert: elrond characterFollowed isNil.
	self assert: elrond currentSite isNil.
	self deny: (wizard followers includes: elrond).
	self deny: (rivendel occupants includes: elrond).
	self assert: wizard currentGeneralInfluence = 20.
	self assert: gandalf currentDirectIfnluence = 10.
	wizard recruit: elrond at: rivendel under: gandalf.
	self assert: (elrond characterFollowed) = gandalf.
	self assert: (elrond agentFollowed) = wizard.
	self assert: (elrond currentSite) = rivendel.
	self assert: (gandalf followers includes: elrond).
	self assert: (rivendel occupants includes: elrond).
	self assert: wizard currentGeneralInfluence = 20.
	self assert: gandalf currentDirectInfluence = 0.! !
